pub struct ComputeHeadCursorResponse {
pub head_cursor: Option<Cursor>,
}Expand description
Response containing the head cursor for the requested topic and partition.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
Fields
head_cursor: Option<Cursor>The head cursor.